searchData={"items":[{"type":"module","title":"Membrane.VideoCompositor","doc":"A bin responsible for doing framerate conversion on all input videos and piping them into the compositor element.","ref":"Membrane.VideoCompositor.html"},{"type":"module","title":"Bin options - Membrane.VideoCompositor","doc":"Passed via struct `t:Membrane.VideoCompositor.t/0`\n\n- `output_stream_format`  \n\n  ```\n  Membrane.RawVideo.t()\n  ```\n  \n  ***Required***  \n  Stream format for the output video of the compositor\n\n\n- `handler`  \n\n  ```\n  Handler.t()\n  ```\n  \n  ***Required***  \n  Module implementing callbacks reacting to VC events.\n  Specifies how `Membrane.VideoCompositor.Scene` should look like.\n  Describes what VC should compose.\n\n\n\n- `queuing_strategy`  \n\n  ```\n  QueueingStrategy.t()\n  ```\n  \n  Default value: `Membrane.VideoCompositor.QueueingStrategy.Offline`  \n  Specifies used frames queueing strategy\n\n\n\n- `metadata`  \n\n  ```\n  init_metadata()\n  ```\n  \n  Default value: `nil`  \n  User-specified init metadata passed to handler callbacks.\n  Passing init metadata into `c:Membrane.VideoCompositor.Handler.handle_init/1` callback allows\n  the user to alternate custom-implemented init callback logic.","ref":"Membrane.VideoCompositor.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.VideoCompositor","doc":"### `:input`\n\nAccepted formats:\n```\n%RawVideo{pixel_format: :I420}\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nPad options:\n\n- `timestamp_offset`  \n\n  ```\n  Membrane.Time.non_neg()\n  ```\n  \n  Default value: `0`  \n  Input stream PTS offset in nanoseconds. Must be non-negative.\n\n\n- `metadata`  \n\n  ```\n  input_pad_metadata()\n  ```\n  \n  Default value: `nil`  \n  User-specified input stream metadata passed to handler callbacks.\n  Passing pad metadata into `c:Membrane.VideoCompositor.Handler.handle_inputs_change/3`\n  callback, allows the user to alternate custom-implemented callbacks logic,\n  e.g. prioritizing input stream in the `Membrane.VideoCompositor.Scene` structs returned from callback.\n\n\n\n\n### `:output`\n\nAccepted formats:\n```\n%RawVideo{pixel_format: :I420}\n```\n\nDirection: | `:output`\nAvailability: | `:always`","ref":"Membrane.VideoCompositor.html#module-pads"},{"type":"function","title":"Membrane.VideoCompositor.options/0","doc":"Returns description of options available for this module","ref":"Membrane.VideoCompositor.html#options/0"},{"type":"type","title":"Membrane.VideoCompositor.init_metadata/0","doc":"User-specified init metadata passed to handler callbacks.\nPassing init metadata into `c:Membrane.VideoCompositor.Handler.handle_init/1` callback allows\nthe user to alternate custom-implemented init callback logic.","ref":"Membrane.VideoCompositor.html#t:init_metadata/0"},{"type":"type","title":"Membrane.VideoCompositor.init_options/0","doc":"","ref":"Membrane.VideoCompositor.html#t:init_options/0"},{"type":"type","title":"Membrane.VideoCompositor.input_pad_metadata/0","doc":"User-specified input stream metadata passed to handler callbacks.\nPassing pad metadata into `c:Membrane.VideoCompositor.Handler.handle_inputs_change/3`\ncallback, allows the user to alternate custom-implemented callbacks logic,\ne.g. prioritizing input stream in the `Membrane.VideoCompositor.Scene` structs returned from callback.","ref":"Membrane.VideoCompositor.html#t:input_pad_metadata/0"},{"type":"type","title":"Membrane.VideoCompositor.input_pad_options/0","doc":"","ref":"Membrane.VideoCompositor.html#t:input_pad_options/0"},{"type":"type","title":"Membrane.VideoCompositor.input_pad_opts/0","doc":"Options for pad `:input`","ref":"Membrane.VideoCompositor.html#t:input_pad_opts/0"},{"type":"type","title":"Membrane.VideoCompositor.t/0","doc":"Struct containing options for `Membrane.VideoCompositor`","ref":"Membrane.VideoCompositor.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.BaseVideoPlacement","doc":"A struct describing the video position, size and z-value for use with the rust-based compositor\non the output frame, before video transformations.","ref":"Membrane.VideoCompositor.BaseVideoPlacement.html"},{"type":"module","title":"Values - Membrane.VideoCompositor.BaseVideoPlacement","doc":"- position: tuple given in pixels, relative to the top right corner of the output frame,\nrepresents the position on the output frame before transformations\n- size: tuple given in pixels, represents video resolution on the output frame before transformations\n- z_value: float in [0.0, 1.0] range, specifies priority: videos with higher `z_value`s are 'in front' of\nvideos with lower `z_value`s","ref":"Membrane.VideoCompositor.BaseVideoPlacement.html#module-values"},{"type":"module","title":"Examples - Membrane.VideoCompositor.BaseVideoPlacement","doc":"If you want to place the video in the bottom left quarter of the 4k output frame,\nabove videos on 0.0 z_value level:\n\n      iex> alias Membrane.VideoCompositor.BaseVideoPlacement\n      Membrane.VideoCompositor.BaseVideoPlacement\n      iex> %BaseVideoPlacement{ position: {1920, 1080}, size: {1920, 1080}, z_value: 0.5}\n      %Membrane.VideoCompositor.BaseVideoPlacement{\n        position: {1920, 1080},\n        size: {1920, 1080},\n        z_value: 0.5\n      }","ref":"Membrane.VideoCompositor.BaseVideoPlacement.html#module-examples"},{"type":"type","title":"Membrane.VideoCompositor.BaseVideoPlacement.t/0","doc":"","ref":"Membrane.VideoCompositor.BaseVideoPlacement.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.Scene","doc":"Structure representing a top level specification of what is Video Compositor\nsupposed to render.","ref":"Membrane.VideoCompositor.Scene.html"},{"type":"function","title":"Membrane.VideoCompositor.Scene.empty/0","doc":"","ref":"Membrane.VideoCompositor.Scene.html#empty/0"},{"type":"function","title":"Membrane.VideoCompositor.Scene.pads/1","doc":"","ref":"Membrane.VideoCompositor.Scene.html#pads/1"},{"type":"function","title":"Membrane.VideoCompositor.Scene.validate/3","doc":"","ref":"Membrane.VideoCompositor.Scene.html#validate/3"},{"type":"type","title":"Membrane.VideoCompositor.Scene.t/0","doc":"Specify how output frame should look like.\n\nIf input pad isn't specified in `video_configs` it won't be used in composition.","ref":"Membrane.VideoCompositor.Scene.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.VideoConfig","doc":"Structure representing a specification of how Video Compositor\nshould transform single input video.","ref":"Membrane.VideoCompositor.VideoConfig.html"},{"type":"type","title":"Membrane.VideoCompositor.VideoConfig.t/0","doc":"Describe video base placement and transformations.\n\nFor more information view `Elixir.Membrane.VideoCompositor.BaseVideoPlacement` and `Elixir.Membrane.VideoCompositor.Transformations`.","ref":"Membrane.VideoCompositor.VideoConfig.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.Transformations","doc":"Describes all transformations applied to video.\nTransformations can change resolution of frame.\nApplying transformations may change size of\nvideo on the output frame (e.x. adding border to video\nwill make video larger).\nAs a contributor adding a new type of transformation,\nyou must create new struct module type and add it to\nthis type definition.","ref":"Membrane.VideoCompositor.Transformations.html"},{"type":"type","title":"Membrane.VideoCompositor.Transformations.t/0","doc":"","ref":"Membrane.VideoCompositor.Transformations.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.Transformations.CornersRounding","doc":"Describe corners rounding transformation parameter.\nCorner rounding transformation can be imagined as placing four circles with specified radius\nadjoining to frame borders, placed inside frame and making space between circle edge and\nnearest frame corner transparent.","ref":"Membrane.VideoCompositor.Transformations.CornersRounding.html"},{"type":"module","title":"Values - Membrane.VideoCompositor.Transformations.CornersRounding","doc":"- border_radius: non negative integer representing radius of circle \"cutting\"\nframe corner part.","ref":"Membrane.VideoCompositor.Transformations.CornersRounding.html#module-values"},{"type":"module","title":"Examples - Membrane.VideoCompositor.Transformations.CornersRounding","doc":"Example struct describing transformation which rounds corners with 100 pixel radius:\n\n    iex> alias Membrane.VideoCompositor.Transformations.CornersRounding\n    Membrane.VideoCompositor.Transformations.CornersRounding\n    iex> %CornersRounding{ border_radius: 100 }\n    %Membrane.VideoCompositor.Transformations.CornersRounding{\n      border_radius: 100\n    }","ref":"Membrane.VideoCompositor.Transformations.CornersRounding.html#module-examples"},{"type":"type","title":"Membrane.VideoCompositor.Transformations.CornersRounding.t/0","doc":"Describe cropping transformation parameter.","ref":"Membrane.VideoCompositor.Transformations.CornersRounding.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.Transformations.Cropping","doc":"Describe cropping transformation parameters.","ref":"Membrane.VideoCompositor.Transformations.Cropping.html"},{"type":"module","title":"Values - Membrane.VideoCompositor.Transformations.Cropping","doc":"- crop_top_left_corner: tuple representing coords (in [0, 1] range) of\ntop left corner of the visible part of video\n- crop_size: tuple representing width and height (in [0, 1] range) of\nthe visible part of video\n- cropped_video_position: optional atom, describe whether cropped video part should\nremain in cropped part or should be in position of video before transformation.\nFor more reference see Examples section below.","ref":"Membrane.VideoCompositor.Transformations.Cropping.html#module-values"},{"type":"module","title":"Examples - Membrane.VideoCompositor.Transformations.Cropping","doc":"Struct describing transformation, which displays only bottom right quarter of input\n  video, with cropped part remaining in its position:\n\n    iex> alias Membrane.VideoCompositor.Transformations.Cropping\n    Membrane.VideoCompositor.Transformations.Cropping\n    iex> %Cropping{\n      crop_top_left_corner: {0.5, 0.5},\n      crop_size: {0.5, 0.5},\n      cropped_video_position: :crop_part_position # can be omitted, this is default value\n    }\n    %Membrane.VideoCompositor.Transformations.Cropping{\n      crop_top_left_corner: {0.5, 0.5},\n      crop_size: {0.5, 0.5},\n      cropped_video_position: :crop_part_position\n    }\n\n  Struct describing transformation, which displays only right part\n  of input video in left part of input video:\n\n    iex> alias Membrane.VideoCompositor.Transformations.Cropping\n      Membrane.VideoCompositor.Transformations.Cropping\n      iex> %Cropping{\n        crop_top_left_corner: {0.5, 0.0},\n        crop_size: {0.5, 1.0},\n        cropped_video_position: :input_position\n      }\n      %Membrane.VideoCompositor.Transformations.Cropping{\n        crop_top_left_corner: {0.5, 0.0},\n        crop_size: {0.5, 1.0},\n        cropped_video_position: :input_position\n      }","ref":"Membrane.VideoCompositor.Transformations.Cropping.html#module-examples"},{"type":"type","title":"Membrane.VideoCompositor.Transformations.Cropping.t/0","doc":"Describe cropping transformation parameters.","ref":"Membrane.VideoCompositor.Transformations.Cropping.html#t:t/0"},{"type":"behaviour","title":"Membrane.VideoCompositor.Handler","doc":"Module defining behaviour of handlers.\n\nImplementing handler allows to provide custom implementation and\nreact to various events, among others by setting a new scene and\nthe inner custom state.","ref":"Membrane.VideoCompositor.Handler.html"},{"type":"callback","title":"Membrane.VideoCompositor.Handler.handle_info/3","doc":"Callback invoked when video compositor receives a message\nthat is not recognized as an internal membrane message.\n\nThis callback allows one to communicate with a Video Compositor by\nsending custom messages and reacting to them.","ref":"Membrane.VideoCompositor.Handler.html#c:handle_info/3"},{"type":"callback","title":"Membrane.VideoCompositor.Handler.handle_init/1","doc":"Callback invoked upon initialization of Video Compositor.","ref":"Membrane.VideoCompositor.Handler.html#c:handle_init/1"},{"type":"callback","title":"Membrane.VideoCompositor.Handler.handle_inputs_change/3","doc":"Callback invoked upon change of VC `t:inputs()`.\n\n`inputs` changing input videos:\n- video added\n- video removed\n- video stream format change","ref":"Membrane.VideoCompositor.Handler.html#c:handle_inputs_change/3"},{"type":"type","title":"Membrane.VideoCompositor.Handler.context/0","doc":"Contains state of VC before handling event invoking callback.","ref":"Membrane.VideoCompositor.Handler.html#t:context/0"},{"type":"type","title":"Membrane.VideoCompositor.Handler.immediate_callback_return/0","doc":"Type of a valid return value from the callback. By returning this type,\nthe scene will be changed immediate, i.e. at the moment when the event happens.","ref":"Membrane.VideoCompositor.Handler.html#t:immediate_callback_return/0"},{"type":"type","title":"Membrane.VideoCompositor.Handler.inputs/0","doc":"Describe all VC input videos used in composition.","ref":"Membrane.VideoCompositor.Handler.html#t:inputs/0"},{"type":"type","title":"Membrane.VideoCompositor.Handler.state/0","doc":"Type of user-managed inner state of the handler.","ref":"Membrane.VideoCompositor.Handler.html#t:state/0"},{"type":"type","title":"Membrane.VideoCompositor.Handler.t/0","doc":"Module implementing `Membrane.VideoCompositor.Handler` behaviour.","ref":"Membrane.VideoCompositor.Handler.html#t:t/0"},{"type":"type","title":"Membrane.VideoCompositor.Handler.timed_callback_return/0","doc":"Type of a valid return value from callback allowing to pick start time of a new scene.","ref":"Membrane.VideoCompositor.Handler.html#t:timed_callback_return/0"},{"type":"module","title":"Membrane.VideoCompositor.Handler.InputProperties","doc":"Defines properties of VC input video passed to callbacks.","ref":"Membrane.VideoCompositor.Handler.InputProperties.html"},{"type":"type","title":"Membrane.VideoCompositor.Handler.InputProperties.t/0","doc":"","ref":"Membrane.VideoCompositor.Handler.InputProperties.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.QueueingStrategy","doc":"Defines possible VideoCompositor frames and events queueing strategies.","ref":"Membrane.VideoCompositor.QueueingStrategy.html"},{"type":"type","title":"Membrane.VideoCompositor.QueueingStrategy.t/0","doc":"Defines possible queueing strategies.\n\nFor specific strategy description, view:\n  - `Membrane.VideoCompositor.QueueingStrategy.Live`\n  - `Membrane.VideoCompositor.QueueingStrategy.Offline`","ref":"Membrane.VideoCompositor.QueueingStrategy.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.QueueingStrategy.Live","doc":"Live queueing strategy, suitable for real-time processing, like live streams.\n\nEvery `1 / output fps` seconds after start of composition (view `t:latency/0`)\ncomposes frames from every input stream with the smallest pts difference to output frame pts.","ref":"Membrane.VideoCompositor.QueueingStrategy.Live.html"},{"type":"type","title":"Membrane.VideoCompositor.QueueingStrategy.Live.eos_strategy/0","doc":"Specifies possible strategies for VideoCompositor to send `t:Membrane.Element.Action.end_of_stream/0`.","ref":"Membrane.VideoCompositor.QueueingStrategy.Live.html#t:eos_strategy/0"},{"type":"type","title":"Strategies: - Membrane.VideoCompositor.QueueingStrategy.Live.eos_strategy/0","doc":"- In the `:all_inputs_eos` strategy VideoCompositor sends EOS after receiving EOSs from all input pads.\n- In the `:schedule_eos` strategy VideoCompositor sends EOS after receiving `t:schedule_eos_message/0` and EOSs\n  from all input pads.\n  If all input pads sent EOS and VideoCompositor hasn't received the `t:schedule_eos_message/0` message,\n  VC will produce frames black frames until it receives the `t:schedule_eos_message/0` message.\n  This is useful, when e.g. some peer connects to a VideoCompositor via the live streaming application. His connection\n  can be dropped and restored multiple times. With this strategy, user can control when VC should send EOS.","ref":"Membrane.VideoCompositor.QueueingStrategy.Live.html#t:eos_strategy/0-strategies"},{"type":"type","title":"Membrane.VideoCompositor.QueueingStrategy.Live.latency/0","doc":"Latency specifies when VideoCompositor will start producing frames.\n\nLatency can be set to:\n  - `t:Membrane.Time.non_neg/0` - a fixed time, after which VC will start composing frames,\n    Setting latency to a higher value allows VideoCompositor to await longer for input frames,\n    but results in higher output stream latency and RAM usage.\n  - `:wait_for_start_event` value, which awaits for `t:start_composing_message/0` to trigger / schedule composing.\n    Be aware that VC enqueues all received frames, so not sending `t:start_composing_message/0` / sending it late, will\n    result in high RAM usage.\n\nIt doesn't modify output frames pts.","ref":"Membrane.VideoCompositor.QueueingStrategy.Live.html#t:latency/0"},{"type":"type","title":"Membrane.VideoCompositor.QueueingStrategy.Live.schedule_eos_message/0","doc":"Specifies how message scheduling EOS should look like.\n\nFor more information on scheduling EOS see: `t:eos_strategy/0`.","ref":"Membrane.VideoCompositor.QueueingStrategy.Live.html#t:schedule_eos_message/0"},{"type":"type","title":"Membrane.VideoCompositor.QueueingStrategy.Live.start_timer_message/0","doc":"Specifies the message that triggers/schedule the start of VC composing.","ref":"Membrane.VideoCompositor.QueueingStrategy.Live.html#t:start_timer_message/0"},{"type":"type","title":"Values: - Membrane.VideoCompositor.QueueingStrategy.Live.start_timer_message/0","doc":"- After receiving `:start_composing` message, VC will immediately start composing.\n  - After receiving `{:start_composing, delay :: Membrane.Time.non_neg()}`, VC will start composing after\n    the time specified by `delay`","ref":"Membrane.VideoCompositor.QueueingStrategy.Live.html#t:start_timer_message/0-values"},{"type":"type","title":"Membrane.VideoCompositor.QueueingStrategy.Live.t/0","doc":"Describes parameters of live queueing strategy.\n\nFor more information, view: `t:latency/0`","ref":"Membrane.VideoCompositor.QueueingStrategy.Live.html#t:t/0"},{"type":"module","title":"Membrane.VideoCompositor.QueueingStrategy.Offline","doc":"Offline queueing strategy, suitable for non-real-time processing.\n\nIn this strategy frames are sent to the compositor only when all added input pads queues,\nwith timestamp offset lower or equal to composed buffer pts,\nhave at least one frame.","ref":"Membrane.VideoCompositor.QueueingStrategy.Offline.html"},{"type":"type","title":"Membrane.VideoCompositor.QueueingStrategy.Offline.t/0","doc":"","ref":"Membrane.VideoCompositor.QueueingStrategy.Offline.html#t:t/0"},{"type":"extras","title":"Membrane Video Compositor Plugin","doc":"# Membrane Video Compositor Plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_video_compositor_plugin.svg)](https://hex.pm/packages/membrane_video_compositor_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_video_compositor_plugin)\n[![CircleCI](https://dl.circleci.com/status-badge/img/gh/membraneframework/membrane_video_compositor_plugin/tree/master.svg?style=svg)](https://dl.circleci.com/status-badge/redirect/gh/membraneframework/membrane_video_compositor_plugin/tree/master)\n\nMembrane plugin that accepts multiple video inputs, transforms them according to provided transformations and composes them into a single output video.\n\nIt is part of [Membrane Multimedia Framework](https://membraneframework.org).","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane Video Compositor Plugin","doc":"The package can be installed by adding `membrane_video_compositor_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_video_compositor_plugin, \"~> 0.7.0\"}\n  ]\nend\n```\n\nSince parts of this package are implemented in Rust, you need to have a Rust installation to compile this package. You can get one [here](https://rustup.rs/)","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Membrane Video Compositor Plugin","doc":"Before jumping into Livebook, check out this [installation guide](https://github.com/membraneframework/guide/tree/master/livebook_examples).\nNote that it's running on the previous version of this plugin.\n\n[![Run in Livebook](https://livebook.dev/badge/v1/blue.svg)](https://livebook.dev/run?url=https%3A%2F%2Fgithub.com%2Fmembraneframework%2Fguide%2Fblob%2Fmaster%2Flivebook_examples%2Fvideo_compositor%2Fvideo_compositor.livemd)","ref":"readme.html#usage"},{"type":"extras","title":"Copyright and License - Membrane Video Compositor Plugin","doc":"Copyright 2022, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_video_compositor_plugin)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_video_compositor_plugin)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2022 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}